==> rtai-0.2.tgz: rtai-0.2/include/rtai_sched.h <==
#ifndef __RT__SCHED__
#define __RT__SCHED__

#define RT_HIGHEST_PRIORITY         0
#define RT_LOWEST_PRIORITY 0x7fffFfff

#define READY        1
#define SUSPENDED    2
#define DELAYED      4
#define SEMAPHORE    8
#define SEND        16
#define RECEIVE     32
#define RPC         64
#define RETURN     128
#define RUNNING    256
#define DELETED    512

struct rt_queue {
	struct rt_queue *prev;
	struct rt_queue *next;
	struct rt_task_struct *task;
};

typedef struct rt_queue QUEUE;

struct rt_semaphore {
	int count;
	int magic;
	struct rt_queue queue;
};

typedef struct rt_semaphore SEM;

struct rt_task_struct {
	int *stack;
	int uses_fpu;
	int magic;
	int state;
	unsigned long runnable_on_cpus;
	int *stack_bottom;
	int priority;
	int base_priority;
	RTIME period;
	RTIME resume_time;
	struct rt_queue queue;
	union {struct rt_task_struct *task; SEM *sem;} blocked_on;
	struct rt_queue msg_queue;
	unsigned int msg;
	void (*signal)(void);
	long fpu_reg[27];
	struct rt_task_struct *prev;
	struct rt_task_struct *next;
};

typedef struct rt_task_struct RT_TASK;


extern int rt_task_init(RT_TASK *task, void (*rt_thread)(int), int data,
				int stack_size, int priority, int uses_fpu,
				void(*signal)(void));

extern void rt_set_runnable_on_cpus(RT_TASK *task, unsigned int cpu_mask);

extern int rt_task_delete(RT_TASK *task);

extern int rt_get_task_state(RT_TASK *task);

extern void rt_set_oneshot_mode(void);

extern void rt_set_periodic_mode(void);

extern RTIME start_rt_timer(int period);

extern void stop_rt_timer(void);

extern RT_TASK *rt_whoami(void);

extern int rt_task_signal_handler(RT_TASK *task, void (*handler)(void));

extern int rt_task_use_fpu(RT_TASK *task, int use_fpu_flag);
  
extern void rt_linux_use_fpu(int use_fpu_flag);

extern void rt_preempt_always(int yes_no);

extern RTIME count2nano(RTIME timercounts);

extern RTIME nano2count(RTIME nanosecs);
  
extern RTIME rt_get_time(void);

extern RTIME rt_get_time_ns(void);

extern RTIME rt_get_cpu_time_ns(void);

extern void rt_task_yield(void);

extern int rt_task_suspend(RT_TASK *task);

extern int rt_task_resume(RT_TASK *task);

extern int rt_task_make_periodic(RT_TASK *task, RTIME start_time, RTIME period);

extern void rt_task_wait_period(void);

extern RTIME next_period(void);

extern void rt_busy_sleep(int nanosecs);

extern void rt_sleep(RTIME delay);

extern void rt_sleep_until(RTIME time);

extern void rt_sem_init(SEM *sem, int value);

extern int rt_sem_delete(SEM *sem);

extern int rt_sem_signal(SEM *sem);

extern int rt_sem_wait(SEM *sem);

extern int rt_sem_wait_if(SEM *sem);

extern int rt_sem_wait_until(SEM *sem, RTIME time);

extern int rt_sem_wait_timed(SEM *sem, RTIME delay);

extern RT_TASK *rt_send(RT_TASK *task, unsigned int msg);

extern RT_TASK *rt_send_if(RT_TASK *task, unsigned int msg);

extern RT_TASK *rt_send_until(RT_TASK *task, unsigned int msg, RTIME time);

extern RT_TASK *rt_send_timed(RT_TASK *task, unsigned int msg, RTIME delay);

extern RT_TASK *rt_receive(RT_TASK *task, unsigned int *msg);

extern RT_TASK *rt_receive_if(RT_TASK *task, unsigned int *msg);

extern RT_TASK *rt_receive_until(RT_TASK *task, unsigned int *msg, RTIME time);

extern RT_TASK *rt_receive_timed(RT_TASK *task, unsigned int *msg, RTIME delay);

extern RT_TASK *rt_rpc(RT_TASK *task, unsigned int to_do, unsigned int *result);

extern RT_TASK *rt_rpc_if(RT_TASK *task, unsigned int to_do, unsigned int *result);

extern RT_TASK *rt_rpc_until(RT_TASK *task, unsigned int to_do, unsigned int *result,
								 RTIME time);
extern RT_TASK *rt_rpc_timed(RT_TASK *task, unsigned int to_do, unsigned int *result,
								 RTIME delay);
extern int rt_isrpc(RT_TASK *task);

extern RT_TASK *rt_return(RT_TASK *task, unsigned int result);

#endif

==> rtai-0.3.tgz: rtai-0.3/include/rtai_sched.h <==
#ifndef __RT__SCHED__
#define __RT__SCHED__

#ifdef INTERFACE_TO_LINUX
#define RT_LINUX_PRIORITY 0x7fffFfff
#endif

#define RT_HIGHEST_PRIORITY         0
#define RT_LOWEST_PRIORITY 0x3fffFfff

#define READY        1
#define SUSPENDED    2
#define DELAYED      4
#define SEMAPHORE    8
#define SEND        16
#define RECEIVE     32
#define RPC         64
#define RETURN     128
#define RUNNING    256
#define DELETED    512

struct rt_queue {
	struct rt_queue *prev;
	struct rt_queue *next;
	struct rt_task_struct *task;
};

typedef struct rt_queue QUEUE;

struct rt_semaphore {
	int count;
	int magic;
	struct rt_queue queue;
};

typedef struct rt_semaphore SEM;

struct rt_task_struct {
	int *stack;
	int uses_fpu;
	int magic;
	int state;
	unsigned long runnable_on_cpus;
	int *stack_bottom;
	int priority;
	int base_priority;
	RTIME period;
	RTIME resume_time;
	struct rt_queue queue;
	union {struct rt_task_struct *task; SEM *sem;} blocked_on;
	struct rt_queue msg_queue;
	unsigned int msg;
	void (*signal)(void);
	long fpu_reg[27];
	struct rt_task_struct *prev;
	struct rt_task_struct *next;
};

typedef struct rt_task_struct RT_TASK;


extern int rt_task_init(RT_TASK *task, void (*rt_thread)(int), int data,
				int stack_size, int priority, int uses_fpu,
				void(*signal)(void));

extern void rt_set_runnable_on_cpus(RT_TASK *task, unsigned int cpu_mask);

extern int rt_task_delete(RT_TASK *task);

extern int rt_get_timer_cpu(void);

extern void rt_set_oneshot_mode(void);

extern void rt_set_periodic_mode(void);

extern RTIME start_rt_timer(int period);

extern void stop_rt_timer(void);

extern RT_TASK *rt_whoami(void);

extern int rt_task_signal_handler(RT_TASK *task, void (*handler)(void));

extern int rt_task_use_fpu(RT_TASK *task, int use_fpu_flag);
  
extern void rt_linux_use_fpu(int use_fpu_flag);

extern void rt_preempt_always(int yes_no);

extern RTIME count2nano(RTIME timercounts);

extern RTIME nano2count(RTIME nanosecs);
  
extern RTIME rt_get_time(void);

extern RTIME rt_get_time_ns(void);

extern RTIME rt_get_cpu_time_ns(void);

extern void rt_task_yield(void);

extern int rt_task_suspend(RT_TASK *task);

extern int rt_task_resume(RT_TASK *task);

extern int rt_task_make_periodic(RT_TASK *task, RTIME start_time, RTIME period);

extern void rt_task_wait_period(void);

extern RTIME next_period(void);

extern void rt_busy_sleep(int nanosecs);

extern void rt_sleep(RTIME delay);

extern void rt_sleep_until(RTIME time);

extern void rt_sem_init(SEM *sem, int value);

extern int rt_sem_delete(SEM *sem);

extern int rt_sem_signal(SEM *sem);

extern int rt_sem_wait(SEM *sem);

extern int rt_sem_wait_if(SEM *sem);

extern int rt_sem_wait_until(SEM *sem, RTIME time);

extern int rt_sem_wait_timed(SEM *sem, RTIME delay);

extern RT_TASK *rt_send(RT_TASK *task, unsigned int msg);

extern RT_TASK *rt_send_if(RT_TASK *task, unsigned int msg);

extern RT_TASK *rt_send_until(RT_TASK *task, unsigned int msg, RTIME time);

extern RT_TASK *rt_send_timed(RT_TASK *task, unsigned int msg, RTIME delay);

extern RT_TASK *rt_receive(RT_TASK *task, unsigned int *msg);

extern RT_TASK *rt_receive_if(RT_TASK *task, unsigned int *msg);

extern RT_TASK *rt_receive_until(RT_TASK *task, unsigned int *msg, RTIME time);

extern RT_TASK *rt_receive_timed(RT_TASK *task, unsigned int *msg, RTIME delay);

extern RT_TASK *rt_rpc(RT_TASK *task, unsigned int to_do, unsigned int *result);

extern RT_TASK *rt_rpc_if(RT_TASK *task, unsigned int to_do, unsigned int *result);

extern RT_TASK *rt_rpc_until(RT_TASK *task, unsigned int to_do, unsigned int *result,
								 RTIME time);
extern RT_TASK *rt_rpc_timed(RT_TASK *task, unsigned int to_do, unsigned int *result,
								 RTIME delay);
extern int rt_isrpc(RT_TASK *task);

extern RT_TASK *rt_return(RT_TASK *task, unsigned int result);

#endif
